@@ -5,26 +5,27 @@
 
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx.ext.autodoc',
+extensions = ['sphinxcontrib.apidoc',
               'sphinx.ext.viewcode',
+              'sphinxcontrib.rsvgconverter',
+              'openstackdocstheme',
               ]
 
-try:
-    import openstackdocstheme
-    extensions.append('openstackdocstheme')
-except ImportError:
-    openstackdocstheme = None
-
-repository_name = 'openstack/python-ironic-inspector-client'
-bug_project = 'python-ironic-inspector-client'
-bug_tag = ''
-html_last_updated_fmt = '%Y-%m-%d %H:%M'
+openstackdocs_repo_name = 'openstack/python-ironic-inspector-client'
+openstackdocs_pdf_link = True
+openstackdocs_use_storyboard = True
 
 wsme_protocols = ['restjson']
 
-# autodoc generation is a bit aggressive and a nuisance when doing heavy
-# text edit cycles.
-# execute "export SPHINX_DEBUG=1" in your terminal to disable
+# sphinxcontrib.apidoc options
+apidoc_module_dir = '../../ironic_inspector_client'
+apidoc_output_dir = 'reference/api'
+apidoc_excluded_paths = [
+    'test/*',
+    'test',
+    'common/i18n*',
+    'shell*']
+apidoc_separate_modules = True
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
@@ -36,20 +37,8 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-project = u'Ironic Inspector Client'
 copyright = u'OpenStack Foundation'
 
-# The version info for the project you're documenting, acts as replacement for
-# |version| and |release|, also used in various other places throughout the
-# built documents.
-#
-# The short X.Y version.
-from ironic_inspector_client import version as il_version
-# The full version, including alpha/beta/rc tags.
-release = il_version.version_info.release_string()
-# The short X.Y version.
-version = il_version.version_info.version_string()
-
 # A list of ignored prefixes for module index sorting.
 modindex_common_prefix = ['ironic_inspector_client']
 
@@ -67,17 +56,15 @@ pygments_style = 'sphinx'
 
 # The theme to use for HTML and HTML Help pages.  Major themes that come with
 # Sphinx are currently 'default' and 'sphinxdoc'.
-if openstackdocstheme is not None:
-    html_theme = 'openstackdocs'
-else:
-    html_theme = 'default'
+html_theme = 'openstackdocs'
 #html_theme_path = ["."]
 #html_theme = '_theme'
 #html_static_path = ['_static']
 
 # Output file base name for HTML help builder.
-htmlhelp_basename = '%sdoc' % project
+htmlhelp_basename = 'python-ironic-inspector-clientdoc'
 
+latex_use_xindy = False
 
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass
@@ -85,8 +72,8 @@ htmlhelp_basename = '%sdoc' % project
 latex_documents = [
     (
         'index',
-        '%s.tex' % project,
-        u'%s Documentation' % project,
+        'doc-python-ironic-inspector-client.tex',
+        u'Python Ironic Inspector Client Documentation',
         u'OpenStack Foundation',
         'manual'
     ),
